@@ -1,5 +1,9 @@
 from dataclasses import dataclass
 
+from statsig import statsig_environment_tier
+
+def _str_or_none(field):
+    return str(field) if field is not None else None
 
 @dataclass
 class StatsigUser:
@@ -28,15 +32,15 @@ class StatsigUser:
 
     def to_dict(self, forEvaluation=False):
         user_nullable = {
-            'userID': self.user_id,
-            'email': self.email,
-            'ip': self.ip,
-            'userAgent': self.user_agent,
-            'country': self.country,
-            'locale': self.locale,
-            'appVersion': self.app_version,
+            'userID': _str_or_none(self.user_id),
+            'email': _str_or_none(self.email),
+            'ip': _str_or_none(self.ip),
+            'userAgent': _str_or_none(self.user_agent),
+            'country': _str_or_none(self.country),
+            'locale': _str_or_none(self.locale),
+            'appVersion': _str_or_none(self.app_version),
             'custom': self.custom,
-            'statsigEnvironment': self._statsig_environment,
+            'statsigEnvironment': self._get_environment(),
             'customIDs': self.custom_ids,
         }
 
@@ -44,3 +48,18 @@ class StatsigUser:
             user_nullable["privateAttributes"] = self.private_attributes
 
         return {k: v for k, v in user_nullable.items() if v is not None}
+
+    def _get_environment(self):
+        if self._statsig_environment is None or self._statsig_environment['tier'] is None:
+            return None
+
+        tier = self._statsig_environment['tier']
+        if isinstance(tier, str):
+            return {'tier': tier}
+
+        if isinstance(tier, statsig_environment_tier.StatsigEnvironmentTier):
+            return {'tier': tier.value}
+
+        return None
+
+    
\ No newline at end of file
